package com.ylx.massage.service;

import java.util.List;
import com.ylx.massage.domain.MaTechnician;
import com.ylx.massage.domain.vo.MaTechnicianAppAddVo;

/**
 * 技师Service接口
 *
 * @author ylx
 * @date 2024-03-22
 */
public interface IMaTechnicianService
{
    /**
     * 查询技师
     *
     * @param id 技师主键
     * @return 技师
     */
    public MaTechnician selectMaTechnicianById(Long id);

    /**
     * 查询技师列表
     *
     * @param maTechnician 技师
     * @return 技师集合
     */
    public List<MaTechnician> selectMaTechnicianList(MaTechnician maTechnician);

    /**
     * 新增技师
     *
     * @param maTechnician 技师
     * @return 结果
     */
    public int insertMaTechnician(MaTechnicianAppAddVo maTechnicianAppAddVo);

    /**
     * 修改技师
     *
     * @param maTechnician 技师
     * @return 结果
     */
    public int updateMaTechnician(MaTechnicianAppAddVo maTechnicianAppAddVo);

    /**
     * 批量删除技师
     *
     * @param ids 需要删除的技师主键集合
     * @return 结果
     */
    public int deleteMaTechnicianByIds(Long[] ids);

    /**
     * 删除技师信息
     *
     * @param id 技师主键
     * @return 结果
     */
    public int deleteMaTechnicianById(Long id);
}
